Re-export types from the http crate used in this module.
Structs
- Header
Map - Metadata attributes used by the Client::open_object.
- Method
- HTTP method used by the SignedUrlBuilder.
Re-export types from the http crate used in this module.