The messages and enums that are part of this client library.
Modules
- bucket
- Defines additional types related to Bucket.
- compose_
object_ request - Defines additional types related to ComposeObjectRequest.
- finding_
summary - Defines additional types related to FindingSummary.
- intelligence_
config - Defines additional types related to IntelligenceConfig.
- intelligence_
finding - Defines additional types related to IntelligenceFinding.
- object
- Defines additional types related to Object.
- storage_
layout - Defines additional types related to StorageLayout.
- summarize_
intelligence_ findings_ request - Defines additional types related to SummarizeIntelligenceFindingsRequest.
Structs
- Anywhere
Cache - An Anywhere Cache Instance.
- Bucket
- A bucket.
- Bucket
Access Control - An access-control entry.
- Common
Long Running Operation Metadata - The message contains metadata that is common to all Storage Control
long-running operations, present in its
google.longrunning.Operationmessages, and accessible viametadata.common_metadata. - Common
Object Request Params - Parameters that can be passed to any object request.
- Compose
Object Request - Request message for ComposeObject.
- Create
Anywhere Cache Metadata - Message returned in the metadata field of the Operation resource for CreateAnywhereCache operations.
- Create
Anywhere Cache Request - Request message for CreateAnywhereCache.
- Create
Bucket Request - Request message for CreateBucket.
- Create
Folder Request - Request message for CreateFolder. This operation is only applicable to a hierarchical namespace enabled bucket.
- Create
Managed Folder Request - Request message for CreateManagedFolder.
- Customer
Encryption - Describes the customer-supplied encryption key mechanism used to store an object’s data at rest.
- Delete
Bucket Request - Request message for DeleteBucket.
- Delete
Folder Recursive Metadata - Message returned in the metadata field of the Operation resource for DeleteFolderRecursive operations.
- Delete
Folder Recursive Request - Request message for DeleteFolderRecursive.
- Delete
Folder Request - Request message for DeleteFolder. This operation is only applicable to a hierarchical namespace enabled bucket.
- Delete
Managed Folder Request - DeleteManagedFolder RPC request message.
- Delete
Object Request - Request message for deleting an object.
- Disable
Anywhere Cache Request - Request message for DisableAnywhereCache.
- Finding
Summary - A summary of findings generated for an organization, a folder, or a project.
- Folder
- A folder resource. This resource can only exist in a hierarchical namespace enabled bucket.
- GetAnywhere
Cache Request - Request message for GetAnywhereCache.
- GetBucket
Request - Request message for GetBucket.
- GetFolder
Intelligence Config Request - Request message to get the
IntelligenceConfigresource associated with your folder. - GetFolder
Request - Request message for GetFolder. This operation is only applicable to a hierarchical namespace enabled bucket.
- GetIntelligence
Finding Request - Request message to get the
IntelligenceFindingresource associated with a project. - GetIntelligence
Finding Revision Request - Request message to get the
IntelligenceFindingRevisionresource associated with a project. - GetManaged
Folder Request - Request message for GetManagedFolder.
- GetObject
Request - Request message for GetObject.
- GetOrganization
Intelligence Config Request - Request message to get the
IntelligenceConfigresource associated with your organization. - GetProject
Intelligence Config Request - Request message to get the
IntelligenceConfigresource associated with your project. - GetStorage
Layout Request - Request message for GetStorageLayout.
- Intelligence
Config - The
IntelligenceConfigresource associated with your organization, folder, or project. - Intelligence
Finding - The
IntelligenceFindingresource that represents a security, performance, or cost-related finding about a project or bucket. - Intelligence
Finding Revision - An
IntelligenceFindingRevisionrepresents a specific revision of anIntelligenceFindingresource. - List
Anywhere Caches Request - Request message for ListAnywhereCaches.
- List
Anywhere Caches Response - Response message for ListAnywhereCaches.
- List
Buckets Request - Request message for ListBuckets.
- List
Buckets Response - Response message for ListBuckets.
- List
Folders Request - Request message for ListFolders. This operation is only applicable to a hierarchical namespace enabled bucket.
- List
Folders Response - Response message for ListFolders.
- List
Intelligence Finding Revisions Request - Request message to list
IntelligenceFindingRevisionresources associated with a project. - List
Intelligence Finding Revisions Response - Response message to list
IntelligenceFindingRevisionresources associated with a project. - List
Intelligence Findings Request - Request message to list
IntelligenceFindingresources associated with a project. - List
Intelligence Findings Response - Response message to list the
IntelligenceFindingresources associated with a project. - List
Managed Folders Request - Request message for ListManagedFolders.
- List
Managed Folders Response - Response message for ListManagedFolders.
- List
Objects Request - Request message for ListObjects.
- List
Objects Response - The result of a call to Objects.ListObjects
- Lock
Bucket Retention Policy Request - Request message for LockBucketRetentionPolicy.
- Managed
Folder - A managed folder.
- Move
Object Request - Request message for MoveObject.
- Object
- An object.
- Object
Access Control - An access-control entry.
- Object
Checksums - Message used for storing full (not subrange) object checksums.
- Object
Contexts - All contexts of an object grouped by type.
- Object
Custom Context Payload - The payload of a single user-defined object context.
- Owner
- The owner of a specific resource.
- Pause
Anywhere Cache Request - Request message for PauseAnywhereCache.
- Pending
Rename Info - Contains information about a pending rename operation.
- Project
Team - Represents the Viewers, Editors, or Owners of a given project.
- Read
Object Request - Request message for [ReadObject][google.storage.v2.Storage.ReadObject].
- Rename
Folder Metadata - Message returned in the metadata field of the Operation resource for RenameFolder operations.
- Rename
Folder Request - Request message for RenameFolder. This operation is only applicable to a hierarchical namespace enabled bucket.
- Restore
Object Request - Request message for
RestoreObject.
bucket,object, andgenerationmust be set. - Resume
Anywhere Cache Request - Request message for ResumeAnywhereCache.
- Rewrite
Object Request - Request message for RewriteObject.
If the source object is encrypted using a Customer-Supplied Encryption Key
the key information must be provided in the
copy_source_encryption_algorithm,copy_source_encryption_key_bytes, andcopy_source_encryption_key_sha256_bytesfields. If the destination object should be encrypted the keying information should be provided in theencryption_algorithm,encryption_key_bytes, andencryption_key_sha256_bytesfields of thecommon_object_request_params.customer_encryptionfield. - Rewrite
Response - A rewrite response.
- Storage
Layout - The storage layout configuration of a bucket.
- Summarize
Intelligence Findings Request - Request message to summarize the intelligence findings for the specified scope(org, folder or project).
- Summarize
Intelligence Findings Response - Response message to summarize the intelligence findings for a specified scope(org, folder or project).
- Update
Anywhere Cache Metadata - Message returned in the metadata field of the Operation resource for UpdateAnywhereCache operation.
- Update
Anywhere Cache Request - Request message for UpdateAnywhereCache.
- Update
Bucket Request - Request for UpdateBucket method.
- Update
Folder Intelligence Config Request - Request message to update the
IntelligenceConfigresource associated with your folder. - Update
Object Request - Request message for UpdateObject.
- Update
Organization Intelligence Config Request - Request message to update the
IntelligenceConfigresource associated with your organization. - Update
Project Intelligence Config Request - Request message to update the
IntelligenceConfigresource associated with your project. - Write
Object Spec - Describes an attempt to insert an object, possibly over multiple requests.
Enums
- Finding
Category - List of categories a finding falls under.
- Finding
Severity - Severity of the
IntelligenceFindingresource. - Finding
Type - List the finding types.