Module intelligence_finding

Module intelligence_finding 

Defines additional types related to IntelligenceFinding.

Modules

coldline_and_archival_storage_operations_spike
Defines additional types related to ColdlineAndArchivalStorageOperationsSpike.
cross_region_egress_spike
Defines additional types related to CrossRegionEgressSpike.
storage_growth_above_trend
Defines additional types related to StorageGrowthAboveTrend.
throttled_request_spike
Defines additional types related to ThrottledRequestSpike.

Structs

ColdlineAndArchivalStorageOperationsSpike
Represents a finding about a spike in Class A/B operations on Coldline or Archive Cloud Storage objects. This corresponds to the COLD_AND_ARCHIVAL_STORAGE_OPERATIONS_SPIKE finding type.
CrossRegionEgressSpike
Represents a finding about a spike in cross-region egress from Cloud Storage. This corresponds to the CROSS_REGION_EGRESS_SPIKE finding type.
StorageGrowthAboveTrend
Represents a finding about a storage growth above the expected trend. This corresponds to the STORAGE_GROWTH_ABOVE_TREND finding type.
ThrottledRequestSpike
Represents a finding about a spike in throttled requests (429 errors) within a project. This corresponds to the THROTTLED_REQUEST_SPIKE finding type.

Enums

IntelligenceFindingDetails
The specific details of the IntelligenceFinding.