IntelligenceFindingDetails

Enum IntelligenceFindingDetails 

#[non_exhaustive]
pub enum IntelligenceFindingDetails { ColdlineAndArchivalStorageOperationsSpike(Box<ColdlineAndArchivalStorageOperationsSpike>), ThrottledRequestsSpike(Box<ThrottledRequestSpike>), CrossRegionEgressSpike(Box<CrossRegionEgressSpike>), StorageGrowthAboveTrend(Box<StorageGrowthAboveTrend>), }
The specific details of the IntelligenceFinding.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ColdlineAndArchivalStorageOperationsSpike(Box<ColdlineAndArchivalStorageOperationsSpike>)

Output only. IntelligenceFinding about a spike in Class A/B operations on Coldline or Archive Cloud Storage objects.



ThrottledRequestsSpike(Box<ThrottledRequestSpike>)

Output only. IntelligenceFinding about a spike in throttled requests (429 errors) within a project.



CrossRegionEgressSpike(Box<CrossRegionEgressSpike>)

Output only. IntelligenceFinding about a spike in cross-region egress.



StorageGrowthAboveTrend(Box<StorageGrowthAboveTrend>)

Output only. IntelligenceFinding about growth in storage above the expected trend.

Implementations

Source

impl IntelligenceFindingDetails

pub fn from_coldline_and_archival_storage_operations_spike( value: impl Into<Box<ColdlineAndArchivalStorageOperationsSpike>>, ) -> Self

Initializes the enum to the ColdlineAndArchivalStorageOperationsSpike branch.

pub fn from_throttled_requests_spike( value: impl Into<Box<ThrottledRequestSpike>>, ) -> Self

Initializes the enum to the ThrottledRequestsSpike branch.

pub fn from_cross_region_egress_spike( value: impl Into<Box<CrossRegionEgressSpike>>, ) -> Self

Initializes the enum to the CrossRegionEgressSpike branch.

pub fn from_storage_growth_above_trend( value: impl Into<Box<StorageGrowthAboveTrend>>, ) -> Self

Initializes the enum to the StorageGrowthAboveTrend branch.