#[non_exhaustive]pub struct ColdlineAndArchivalStorageOperationsSpike {
pub percentage_increase: f64,
pub total_operations_count: i64,
pub top_buckets: Vec<BucketContribution>,
/* private fields */
}Expand description
Represents a finding about a spike in Class A/B operations on Coldline
or Archive Cloud Storage objects.
This corresponds to the COLD_AND_ARCHIVAL_STORAGE_OPERATIONS_SPIKE
finding type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.percentage_increase: f64Output only. The percentage increase in operations across the project.
total_operations_count: i64Output only. The total count of operations across the project.
top_buckets: Vec<BucketContribution>Output only. A list of the top buckets driving the increase in operations.
Implementations
Sourceimpl ColdlineAndArchivalStorageOperationsSpike
impl ColdlineAndArchivalStorageOperationsSpike
Sourcepub fn set_percentage_increase<T: Into<f64>>(self, v: T) -> Self
pub fn set_percentage_increase<T: Into<f64>>(self, v: T) -> Self
Sets the value of percentage_increase.
Example
ⓘ
let x = ColdlineAndArchivalStorageOperationsSpike::new().set_percentage_increase(42.0);Sourcepub fn set_total_operations_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_operations_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_operations_count.
Example
ⓘ
let x = ColdlineAndArchivalStorageOperationsSpike::new().set_total_operations_count(42);Sourcepub fn set_top_buckets<T, V>(self, v: T) -> Self
pub fn set_top_buckets<T, V>(self, v: T) -> Self
Sets the value of top_buckets.
Example
ⓘ
use google_cloud_storage::model::intelligence_finding::coldline_and_archival_storage_operations_spike::BucketContribution;
let x = ColdlineAndArchivalStorageOperationsSpike::new()
.set_top_buckets([
BucketContribution::default()/* use setters */,
BucketContribution::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ColdlineAndArchivalStorageOperationsSpike
impl Clone for ColdlineAndArchivalStorageOperationsSpike
Sourcefn clone(&self) -> ColdlineAndArchivalStorageOperationsSpike
fn clone(&self) -> ColdlineAndArchivalStorageOperationsSpike
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ColdlineAndArchivalStorageOperationsSpike
impl Default for ColdlineAndArchivalStorageOperationsSpike
Sourcefn default() -> ColdlineAndArchivalStorageOperationsSpike
fn default() -> ColdlineAndArchivalStorageOperationsSpike
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ColdlineAndArchivalStorageOperationsSpike
impl PartialEq for ColdlineAndArchivalStorageOperationsSpike
Sourcefn eq(&self, other: &ColdlineAndArchivalStorageOperationsSpike) -> bool
fn eq(&self, other: &ColdlineAndArchivalStorageOperationsSpike) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ColdlineAndArchivalStorageOperationsSpike