#[non_exhaustive]pub struct CrossRegionEgressSpike {
pub total_egress_bytes: i64,
pub percentage_increase: f64,
pub top_buckets: Vec<BucketContribution>,
/* private fields */
}Expand description
Represents a finding about a spike in cross-region egress from Cloud
Storage.
This corresponds to the CROSS_REGION_EGRESS_SPIKE finding type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.total_egress_bytes: i64Output only. The total cross-region egress volume in bytes across the project.
percentage_increase: f64Output only. The percentage increase in cross-region egress across the project.
top_buckets: Vec<BucketContribution>Output only. A list of top buckets driving the increase in cross-region egress.
Implementations
Sourceimpl CrossRegionEgressSpike
impl CrossRegionEgressSpike
Sourcepub fn set_total_egress_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_egress_bytes<T: Into<i64>>(self, v: T) -> Self
Sets the value of total_egress_bytes.
Example
ⓘ
let x = CrossRegionEgressSpike::new().set_total_egress_bytes(42);Sourcepub fn set_percentage_increase<T: Into<f64>>(self, v: T) -> Self
pub fn set_percentage_increase<T: Into<f64>>(self, v: T) -> Self
Sets the value of percentage_increase.
Example
ⓘ
let x = CrossRegionEgressSpike::new().set_percentage_increase(42.0);Sourcepub fn set_top_buckets<T, V>(self, v: T) -> Self
pub fn set_top_buckets<T, V>(self, v: T) -> Self
Sets the value of top_buckets.
Example
ⓘ
use google_cloud_storage::model::intelligence_finding::cross_region_egress_spike::BucketContribution;
let x = CrossRegionEgressSpike::new()
.set_top_buckets([
BucketContribution::default()/* use setters */,
BucketContribution::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for CrossRegionEgressSpike
impl Clone for CrossRegionEgressSpike
Sourcefn clone(&self) -> CrossRegionEgressSpike
fn clone(&self) -> CrossRegionEgressSpike
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrossRegionEgressSpike
impl Debug for CrossRegionEgressSpike
Sourceimpl Default for CrossRegionEgressSpike
impl Default for CrossRegionEgressSpike
Sourcefn default() -> CrossRegionEgressSpike
fn default() -> CrossRegionEgressSpike
Returns the “default value” for a type. Read more
Sourceimpl Message for CrossRegionEgressSpike
impl Message for CrossRegionEgressSpike
Sourceimpl PartialEq for CrossRegionEgressSpike
impl PartialEq for CrossRegionEgressSpike
Sourcefn eq(&self, other: &CrossRegionEgressSpike) -> bool
fn eq(&self, other: &CrossRegionEgressSpike) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CrossRegionEgressSpike