#[non_exhaustive]pub struct ThrottledRequestSpike {
pub throttled_requests: i64,
pub percentage_increase: f64,
pub top_buckets: Vec<BucketContribution>,
/* private fields */
}Expand description
Represents a finding about a spike in throttled requests (429 errors)
within a project.
This corresponds to the THROTTLED_REQUEST_SPIKE finding type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.throttled_requests: i64Output only. The count of throttled requests across the project.
percentage_increase: f64Output only. The percentage increase in throttled requests across the project.
top_buckets: Vec<BucketContribution>Output only. A list of top buckets driving the increase in throttled requests.
Implementations
Sourceimpl ThrottledRequestSpike
impl ThrottledRequestSpike
Sourcepub fn set_throttled_requests<T: Into<i64>>(self, v: T) -> Self
pub fn set_throttled_requests<T: Into<i64>>(self, v: T) -> Self
Sets the value of throttled_requests.
Example
ⓘ
let x = ThrottledRequestSpike::new().set_throttled_requests(42);Sourcepub fn set_percentage_increase<T: Into<f64>>(self, v: T) -> Self
pub fn set_percentage_increase<T: Into<f64>>(self, v: T) -> Self
Sets the value of percentage_increase.
Example
ⓘ
let x = ThrottledRequestSpike::new().set_percentage_increase(42.0);Sourcepub fn set_top_buckets<T, V>(self, v: T) -> Self
pub fn set_top_buckets<T, V>(self, v: T) -> Self
Sets the value of top_buckets.
Example
ⓘ
use google_cloud_storage::model::intelligence_finding::throttled_request_spike::BucketContribution;
let x = ThrottledRequestSpike::new()
.set_top_buckets([
BucketContribution::default()/* use setters */,
BucketContribution::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ThrottledRequestSpike
impl Clone for ThrottledRequestSpike
Sourcefn clone(&self) -> ThrottledRequestSpike
fn clone(&self) -> ThrottledRequestSpike
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThrottledRequestSpike
impl Debug for ThrottledRequestSpike
Sourceimpl Default for ThrottledRequestSpike
impl Default for ThrottledRequestSpike
Sourcefn default() -> ThrottledRequestSpike
fn default() -> ThrottledRequestSpike
Returns the “default value” for a type. Read more
Sourceimpl Message for ThrottledRequestSpike
impl Message for ThrottledRequestSpike
Sourceimpl PartialEq for ThrottledRequestSpike
impl PartialEq for ThrottledRequestSpike
Sourcefn eq(&self, other: &ThrottledRequestSpike) -> bool
fn eq(&self, other: &ThrottledRequestSpike) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ThrottledRequestSpike