Module managed_folder

Module managed_folder 

Defines additional types related to ManagedFolder.

Modules

rapid_cache_config
Defines additional types related to RapidCacheConfig.

Structs

RapidCacheConfig
Rapid Cache configuration for a managed prefix. This configuration is used to determine how the rapid cache behaves for objects under the managed folder.