#[non_exhaustive]pub struct RapidCachePolicy {
pub rapid_cache_id: String,
pub ingest_on_write: IngestOnWrite,
/* private fields */
}Expand description
Rapid Cache policy for a managed folder.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rapid_cache_id: StringRequired. The identifier for the rapid cache.
ingest_on_write: IngestOnWriteRequired. If enabled, objects in the Managed Folder will be ingested into the cache when they are written.
Implementations
Sourceimpl RapidCachePolicy
impl RapidCachePolicy
Sourcepub fn set_rapid_cache_id<T: Into<String>>(self, v: T) -> Self
pub fn set_rapid_cache_id<T: Into<String>>(self, v: T) -> Self
Sets the value of rapid_cache_id.
Example
ⓘ
let x = RapidCachePolicy::new().set_rapid_cache_id("example");Sourcepub fn set_ingest_on_write<T: Into<IngestOnWrite>>(self, v: T) -> Self
pub fn set_ingest_on_write<T: Into<IngestOnWrite>>(self, v: T) -> Self
Sets the value of ingest_on_write.
Example
ⓘ
use google_cloud_storage::model::managed_folder::rapid_cache_config::rapid_cache_policy::IngestOnWrite;
let x0 = RapidCachePolicy::new().set_ingest_on_write(IngestOnWrite::Enabled);Trait Implementations
Sourceimpl Clone for RapidCachePolicy
impl Clone for RapidCachePolicy
Sourcefn clone(&self) -> RapidCachePolicy
fn clone(&self) -> RapidCachePolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RapidCachePolicy
impl Debug for RapidCachePolicy
Sourceimpl Default for RapidCachePolicy
impl Default for RapidCachePolicy
Sourcefn default() -> RapidCachePolicy
fn default() -> RapidCachePolicy
Returns the “default value” for a type. Read more
Sourceimpl Message for RapidCachePolicy
impl Message for RapidCachePolicy
Sourceimpl PartialEq for RapidCachePolicy
impl PartialEq for RapidCachePolicy
impl StructuralPartialEq for RapidCachePolicy