#[non_exhaustive]pub struct RapidCacheConfig {
pub policies: HashMap<String, RapidCachePolicy>,
/* private fields */
}Expand description
Rapid Cache configuration for a managed prefix. This configuration is used to determine how the rapid cache behaves for objects under the managed folder.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policies: HashMap<String, RapidCachePolicy>Optional. A map of rapid_cache_id to RapidCachePolicy for this prefix. Currently, the key rapid_cache_id is the zone. However, the field is generalized as rapid_cache_id to align the policy lifetime with the cache instance lifetime. This allows for a future transition from zone to a cache id if required.
Implementations
Sourceimpl RapidCacheConfig
impl RapidCacheConfig
Sourcepub fn set_policies<T, K, V>(self, v: T) -> Self
pub fn set_policies<T, K, V>(self, v: T) -> Self