#[non_exhaustive]pub enum Mode {
Unspecified,
Unlocked,
Locked,
UnknownValue(UnknownValue),
}Expand description
Retention mode values.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
No specified mode. Object is not under retention.
Unlocked
Retention period might be decreased or increased. The Retention configuration might be removed. The mode might be changed to locked.
Locked
Retention period might be increased. The Retention configuration cannot be removed. The mode cannot be changed.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Mode::value or Mode::name.
Implementations