#[non_exhaustive]pub struct CreateRapidCacheMetadata {
pub common_metadata: Option<CommonLongRunningOperationMetadata>,
pub rapid_cache_id: Option<String>,
pub zone: Option<String>,
pub ttl: Option<Duration>,
pub admission_policy: Option<String>,
pub ingest_on_write: Option<bool>,
pub cache_type: Option<String>,
/* private fields */
}Expand description
Message returned in the metadata field of the Operation resource for CreateRapidCache operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.common_metadata: Option<CommonLongRunningOperationMetadata>Generic metadata for the long running operation.
rapid_cache_id: Option<String>Rapid Cache ID.
zone: Option<String>The zone in which the cache instance is running. For example, us-central1-a.
ttl: Option<Duration>Rapid Cache entry’s TTL. A cache-level config that is applied to all new cache entries on admission. Default ttl value (24hrs) is applied if not specified in the create request.
admission_policy: Option<String>Anywhere Cache entry Admission Policy in kebab-case (e.g., “admit-on-first-miss”). Default admission policy (admit-on-first-miss) is applied if not specified in the create request.
ingest_on_write: Option<bool>Optional. Specifies whether objects are ingested into the cache upon write. Defaults to false.
cache_type: Option<String>Optional. The type of cache. Either rapid cache or rapid cache ultra.
Implementations
Sourceimpl CreateRapidCacheMetadata
impl CreateRapidCacheMetadata
Sourcepub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets the value of common_metadata.
Example
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = CreateRapidCacheMetadata::new().set_common_metadata(CommonLongRunningOperationMetadata::default()/* use setters */);Sourcepub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets or clears the value of common_metadata.
Example
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = CreateRapidCacheMetadata::new().set_or_clear_common_metadata(Some(CommonLongRunningOperationMetadata::default()/* use setters */));
let x = CreateRapidCacheMetadata::new().set_or_clear_common_metadata(None::<CommonLongRunningOperationMetadata>);Sourcepub fn set_rapid_cache_id<T>(self, v: T) -> Self
pub fn set_rapid_cache_id<T>(self, v: T) -> Self
Sets the value of rapid_cache_id.
Example
let x = CreateRapidCacheMetadata::new().set_rapid_cache_id("example");Sourcepub fn set_or_clear_rapid_cache_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_rapid_cache_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of rapid_cache_id.
Example
let x = CreateRapidCacheMetadata::new().set_or_clear_rapid_cache_id(Some("example"));
let x = CreateRapidCacheMetadata::new().set_or_clear_rapid_cache_id(None::<String>);Sourcepub fn set_or_clear_zone<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_zone<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
Sourcepub fn set_admission_policy<T>(self, v: T) -> Self
pub fn set_admission_policy<T>(self, v: T) -> Self
Sets the value of admission_policy.
Example
let x = CreateRapidCacheMetadata::new().set_admission_policy("example");Sourcepub fn set_or_clear_admission_policy<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_admission_policy<T>(self, v: Option<T>) -> Self
Sets or clears the value of admission_policy.
Example
let x = CreateRapidCacheMetadata::new().set_or_clear_admission_policy(Some("example"));
let x = CreateRapidCacheMetadata::new().set_or_clear_admission_policy(None::<String>);Sourcepub fn set_ingest_on_write<T>(self, v: T) -> Self
pub fn set_ingest_on_write<T>(self, v: T) -> Self
Sets the value of ingest_on_write.
Example
let x = CreateRapidCacheMetadata::new().set_ingest_on_write(true);Sourcepub fn set_or_clear_ingest_on_write<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ingest_on_write<T>(self, v: Option<T>) -> Self
Sets or clears the value of ingest_on_write.
Example
let x = CreateRapidCacheMetadata::new().set_or_clear_ingest_on_write(Some(false));
let x = CreateRapidCacheMetadata::new().set_or_clear_ingest_on_write(None::<bool>);Sourcepub fn set_cache_type<T>(self, v: T) -> Self
pub fn set_cache_type<T>(self, v: T) -> Self
Sets the value of cache_type.
Example
let x = CreateRapidCacheMetadata::new().set_cache_type("example");Sourcepub fn set_or_clear_cache_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cache_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of cache_type.
Example
let x = CreateRapidCacheMetadata::new().set_or_clear_cache_type(Some("example"));
let x = CreateRapidCacheMetadata::new().set_or_clear_cache_type(None::<String>);Trait Implementations
Sourceimpl Clone for CreateRapidCacheMetadata
impl Clone for CreateRapidCacheMetadata
Sourcefn clone(&self) -> CreateRapidCacheMetadata
fn clone(&self) -> CreateRapidCacheMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateRapidCacheMetadata
impl Debug for CreateRapidCacheMetadata
Sourceimpl Default for CreateRapidCacheMetadata
impl Default for CreateRapidCacheMetadata
Sourcefn default() -> CreateRapidCacheMetadata
fn default() -> CreateRapidCacheMetadata
Sourceimpl Message for CreateRapidCacheMetadata
impl Message for CreateRapidCacheMetadata
Sourceimpl PartialEq for CreateRapidCacheMetadata
impl PartialEq for CreateRapidCacheMetadata
impl StructuralPartialEq for CreateRapidCacheMetadata