#[non_exhaustive]pub struct DeleteFolderRecursiveMetadata {
pub common_metadata: Option<CommonLongRunningOperationMetadata>,
pub folder_id: String,
/* private fields */
}Expand description
Message returned in the metadata field of the Operation resource for DeleteFolderRecursive operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.common_metadata: Option<CommonLongRunningOperationMetadata>Generic metadata for the long running operation.
folder_id: StringThe path of the folder recursively deleted.
Implementations
Sourceimpl DeleteFolderRecursiveMetadata
impl DeleteFolderRecursiveMetadata
pub fn new() -> Self
Sourcepub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets the value of common_metadata.
Example
ⓘ
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = DeleteFolderRecursiveMetadata::new().set_common_metadata(CommonLongRunningOperationMetadata::default()/* use setters */);Sourcepub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets or clears the value of common_metadata.
Example
ⓘ
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = DeleteFolderRecursiveMetadata::new().set_or_clear_common_metadata(Some(CommonLongRunningOperationMetadata::default()/* use setters */));
let x = DeleteFolderRecursiveMetadata::new().set_or_clear_common_metadata(None::<CommonLongRunningOperationMetadata>);Trait Implementations
Sourceimpl Clone for DeleteFolderRecursiveMetadata
impl Clone for DeleteFolderRecursiveMetadata
Sourcefn clone(&self) -> DeleteFolderRecursiveMetadata
fn clone(&self) -> DeleteFolderRecursiveMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DeleteFolderRecursiveMetadata
impl Default for DeleteFolderRecursiveMetadata
Sourcefn default() -> DeleteFolderRecursiveMetadata
fn default() -> DeleteFolderRecursiveMetadata
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for DeleteFolderRecursiveMetadata
impl PartialEq for DeleteFolderRecursiveMetadata
Sourcefn eq(&self, other: &DeleteFolderRecursiveMetadata) -> bool
fn eq(&self, other: &DeleteFolderRecursiveMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeleteFolderRecursiveMetadata