#[non_exhaustive]pub struct DeleteFolderRecursiveRequest {
pub name: String,
pub if_metageneration_match: Option<i64>,
pub if_metageneration_not_match: Option<i64>,
pub request_id: String,
/* private fields */
}Expand description
Request message for DeleteFolderRecursive.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the folder being deleted, however all of its contents
will be deleted too. Format:
projects/{project}/buckets/{bucket}/folders/{folder}
if_metageneration_match: Option<i64>Optional. Makes the operation only succeed conditional on whether the root folder’s current metageneration matches the given value.
if_metageneration_not_match: Option<i64>Optional. Makes the operation only succeed conditional on whether the root folder’s current metageneration does not match the given value.
request_id: StringOptional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted.
Implementations
Sourceimpl DeleteFolderRecursiveRequest
impl DeleteFolderRecursiveRequest
pub fn new() -> Self
Sourcepub fn set_if_metageneration_match<T>(self, v: T) -> Self
pub fn set_if_metageneration_match<T>(self, v: T) -> Self
Sets the value of if_metageneration_match.
Example
let x = DeleteFolderRecursiveRequest::new().set_if_metageneration_match(42);Sourcepub fn set_or_clear_if_metageneration_match<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_if_metageneration_match<T>(self, v: Option<T>) -> Self
Sets or clears the value of if_metageneration_match.
Example
let x = DeleteFolderRecursiveRequest::new().set_or_clear_if_metageneration_match(Some(42));
let x = DeleteFolderRecursiveRequest::new().set_or_clear_if_metageneration_match(None::<i32>);Sourcepub fn set_if_metageneration_not_match<T>(self, v: T) -> Self
pub fn set_if_metageneration_not_match<T>(self, v: T) -> Self
Sets the value of if_metageneration_not_match.
Example
let x = DeleteFolderRecursiveRequest::new().set_if_metageneration_not_match(42);Sourcepub fn set_or_clear_if_metageneration_not_match<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_if_metageneration_not_match<T>(self, v: Option<T>) -> Self
Sets or clears the value of if_metageneration_not_match.
Example
let x = DeleteFolderRecursiveRequest::new().set_or_clear_if_metageneration_not_match(Some(42));
let x = DeleteFolderRecursiveRequest::new().set_or_clear_if_metageneration_not_match(None::<i32>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = DeleteFolderRecursiveRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for DeleteFolderRecursiveRequest
impl Clone for DeleteFolderRecursiveRequest
Sourcefn clone(&self) -> DeleteFolderRecursiveRequest
fn clone(&self) -> DeleteFolderRecursiveRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DeleteFolderRecursiveRequest
impl Debug for DeleteFolderRecursiveRequest
Sourceimpl Default for DeleteFolderRecursiveRequest
impl Default for DeleteFolderRecursiveRequest
Sourcefn default() -> DeleteFolderRecursiveRequest
fn default() -> DeleteFolderRecursiveRequest
Sourceimpl PartialEq for DeleteFolderRecursiveRequest
impl PartialEq for DeleteFolderRecursiveRequest
Sourcefn eq(&self, other: &DeleteFolderRecursiveRequest) -> bool
fn eq(&self, other: &DeleteFolderRecursiveRequest) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeleteFolderRecursiveRequest