#[non_exhaustive]pub struct DisableRapidCacheMetadata {
pub common_metadata: Option<CommonLongRunningOperationMetadata>,
pub rapid_cache_id: Option<String>,
pub zone: Option<String>,
pub cache_type: Option<String>,
/* private fields */
}Expand description
Message returned in the metadata field of the Operation resource for DeleteRapidCache operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.common_metadata: Option<CommonLongRunningOperationMetadata>Generic metadata for the long running operation.
rapid_cache_id: Option<String>Rapid Cache ID.
zone: Option<String>The zone in which the cache instance is running. For example, us-central1-a.
cache_type: Option<String>Optional. The type of cache. Either rapid cache or rapid cache ultra.
Implementations
Sourceimpl DisableRapidCacheMetadata
impl DisableRapidCacheMetadata
Sourcepub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets the value of common_metadata.
Example
ⓘ
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = DisableRapidCacheMetadata::new().set_common_metadata(CommonLongRunningOperationMetadata::default()/* use setters */);Sourcepub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets or clears the value of common_metadata.
Example
ⓘ
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = DisableRapidCacheMetadata::new().set_or_clear_common_metadata(Some(CommonLongRunningOperationMetadata::default()/* use setters */));
let x = DisableRapidCacheMetadata::new().set_or_clear_common_metadata(None::<CommonLongRunningOperationMetadata>);Sourcepub fn set_rapid_cache_id<T>(self, v: T) -> Self
pub fn set_rapid_cache_id<T>(self, v: T) -> Self
Sets the value of rapid_cache_id.
Example
ⓘ
let x = DisableRapidCacheMetadata::new().set_rapid_cache_id("example");Sourcepub fn set_or_clear_rapid_cache_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_rapid_cache_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of rapid_cache_id.
Example
ⓘ
let x = DisableRapidCacheMetadata::new().set_or_clear_rapid_cache_id(Some("example"));
let x = DisableRapidCacheMetadata::new().set_or_clear_rapid_cache_id(None::<String>);Sourcepub fn set_or_clear_zone<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_zone<T>(self, v: Option<T>) -> Self
Sourcepub fn set_cache_type<T>(self, v: T) -> Self
pub fn set_cache_type<T>(self, v: T) -> Self
Sets the value of cache_type.
Example
ⓘ
let x = DisableRapidCacheMetadata::new().set_cache_type("example");Sourcepub fn set_or_clear_cache_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cache_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of cache_type.
Example
ⓘ
let x = DisableRapidCacheMetadata::new().set_or_clear_cache_type(Some("example"));
let x = DisableRapidCacheMetadata::new().set_or_clear_cache_type(None::<String>);Trait Implementations
Sourceimpl Clone for DisableRapidCacheMetadata
impl Clone for DisableRapidCacheMetadata
Sourcefn clone(&self) -> DisableRapidCacheMetadata
fn clone(&self) -> DisableRapidCacheMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisableRapidCacheMetadata
impl Debug for DisableRapidCacheMetadata
Sourceimpl Default for DisableRapidCacheMetadata
impl Default for DisableRapidCacheMetadata
Sourcefn default() -> DisableRapidCacheMetadata
fn default() -> DisableRapidCacheMetadata
Returns the “default value” for a type. Read more
Sourceimpl Message for DisableRapidCacheMetadata
impl Message for DisableRapidCacheMetadata
impl StructuralPartialEq for DisableRapidCacheMetadata