#[non_exhaustive]pub struct FindingSummary {
pub type: FindingType,
pub category: FindingCategory,
pub target_resource: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub severity: FindingSeverity,
pub summary_details: Vec<SummaryDetails>,
/* private fields */
}Expand description
A summary of findings generated for an organization, a folder, or a project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: FindingTypeOutput only. The type of the finding.
category: FindingCategoryOutput only. The category of finding.
target_resource: StringOutput only. The fully qualified Cloud resource name for which this
summary was generated.
eg: //cloudresourcemanager.googleapis.com/projects/p1
create_time: Option<Timestamp>Output only. The creation time of the earliest finding that this summary is based on.
update_time: Option<Timestamp>Output only. The time of the most recent update among all the findings that this summary is based on.
severity: FindingSeveritySeverity of the finding.
summary_details: Vec<SummaryDetails>Output only. List of SummaryDetails.
Implementations
Sourceimpl FindingSummary
impl FindingSummary
Sourcepub fn set_type<T: Into<FindingType>>(self, v: T) -> Self
pub fn set_type<T: Into<FindingType>>(self, v: T) -> Self
Sets the value of r#type.
Example
use google_cloud_storage::model::FindingType;
let x0 = FindingSummary::new().set_type(FindingType::ColdlineAndArchivalStorageOperationsSpike);
let x1 = FindingSummary::new().set_type(FindingType::ThrottledRequestSpike);
let x2 = FindingSummary::new().set_type(FindingType::CrossRegionEgressSpike);Sourcepub fn set_category<T: Into<FindingCategory>>(self, v: T) -> Self
pub fn set_category<T: Into<FindingCategory>>(self, v: T) -> Self
Sourcepub fn set_target_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_target_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of target_resource.
Example
let x = FindingSummary::new().set_target_resource("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = FindingSummary::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = FindingSummary::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = FindingSummary::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = FindingSummary::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = FindingSummary::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = FindingSummary::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_severity<T: Into<FindingSeverity>>(self, v: T) -> Self
pub fn set_severity<T: Into<FindingSeverity>>(self, v: T) -> Self
Sourcepub fn set_summary_details<T, V>(self, v: T) -> Self
pub fn set_summary_details<T, V>(self, v: T) -> Self
Sets the value of summary_details.
Example
use google_cloud_storage::model::finding_summary::SummaryDetails;
let x = FindingSummary::new()
.set_summary_details([
SummaryDetails::default()/* use setters */,
SummaryDetails::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for FindingSummary
impl Clone for FindingSummary
Sourcefn clone(&self) -> FindingSummary
fn clone(&self) -> FindingSummary
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FindingSummary
impl Debug for FindingSummary
Sourceimpl Default for FindingSummary
impl Default for FindingSummary
Sourcefn default() -> FindingSummary
fn default() -> FindingSummary
Sourceimpl Message for FindingSummary
impl Message for FindingSummary
Sourceimpl PartialEq for FindingSummary
impl PartialEq for FindingSummary
Sourcefn eq(&self, other: &FindingSummary) -> bool
fn eq(&self, other: &FindingSummary) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FindingSummary