#[non_exhaustive]pub struct IntelligenceFindingRevision {
pub name: String,
pub snapshot: Option<IntelligenceFinding>,
pub create_time: Option<Timestamp>,
/* private fields */
}Expand description
An IntelligenceFindingRevision represents a specific revision of an
IntelligenceFinding resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of IntelligenceFindingRevision.
Format:
projects/{project}/locations/{location}/intelligenceFindings/{intelligence_finding}/revisions/{revision}
snapshot: Option<IntelligenceFinding>Output only. The snapshot of the IntelligenceFinding at the time the
revision was created. This field contains the full finding details as they
existed for the revision.
create_time: Option<Timestamp>Output only. The timestamp when the revision was created.
Implementations
Sourceimpl IntelligenceFindingRevision
impl IntelligenceFindingRevision
Sourcepub fn set_snapshot<T>(self, v: T) -> Selfwhere
T: Into<IntelligenceFinding>,
pub fn set_snapshot<T>(self, v: T) -> Selfwhere
T: Into<IntelligenceFinding>,
Sourcepub fn set_or_clear_snapshot<T>(self, v: Option<T>) -> Selfwhere
T: Into<IntelligenceFinding>,
pub fn set_or_clear_snapshot<T>(self, v: Option<T>) -> Selfwhere
T: Into<IntelligenceFinding>,
Sets or clears the value of snapshot.
Example
ⓘ
use google_cloud_storage::model::IntelligenceFinding;
let x = IntelligenceFindingRevision::new().set_or_clear_snapshot(Some(IntelligenceFinding::default()/* use setters */));
let x = IntelligenceFindingRevision::new().set_or_clear_snapshot(None::<IntelligenceFinding>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = IntelligenceFindingRevision::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = IntelligenceFindingRevision::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = IntelligenceFindingRevision::new().set_or_clear_create_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for IntelligenceFindingRevision
impl Clone for IntelligenceFindingRevision
Sourcefn clone(&self) -> IntelligenceFindingRevision
fn clone(&self) -> IntelligenceFindingRevision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntelligenceFindingRevision
impl Debug for IntelligenceFindingRevision
Sourceimpl Default for IntelligenceFindingRevision
impl Default for IntelligenceFindingRevision
Sourcefn default() -> IntelligenceFindingRevision
fn default() -> IntelligenceFindingRevision
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for IntelligenceFindingRevision
impl PartialEq for IntelligenceFindingRevision
Sourcefn eq(&self, other: &IntelligenceFindingRevision) -> bool
fn eq(&self, other: &IntelligenceFindingRevision) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IntelligenceFindingRevision