#[non_exhaustive]pub struct ListIntelligenceFindingsRequest {
pub parent: String,
pub filter: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message to list IntelligenceFinding resources associated with
a project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent of the IntelligenceFinding resource.
Format: projects/{project}/locations/{location}
filter: StringOptional. The filter expression to be applied.
Supports filtering by type and associated_resources.
page_size: i32Optional. The maximum number of IntelligenceFinding resources to return.
The maximum value is 100; values above 100 will be coerced to 100.
The default value is 100.
page_token: StringOptional. A page token, received from a previous ListIntelligenceFindings
call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
ListIntelligenceFindings must match the call that provided the page
token.
Implementations
Sourceimpl ListIntelligenceFindingsRequest
impl ListIntelligenceFindingsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListIntelligenceFindingsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListIntelligenceFindingsRequest
impl Clone for ListIntelligenceFindingsRequest
Sourcefn clone(&self) -> ListIntelligenceFindingsRequest
fn clone(&self) -> ListIntelligenceFindingsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListIntelligenceFindingsRequest
impl Default for ListIntelligenceFindingsRequest
Sourcefn default() -> ListIntelligenceFindingsRequest
fn default() -> ListIntelligenceFindingsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListIntelligenceFindingsRequest
impl PartialEq for ListIntelligenceFindingsRequest
Sourcefn eq(&self, other: &ListIntelligenceFindingsRequest) -> bool
fn eq(&self, other: &ListIntelligenceFindingsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListIntelligenceFindingsRequest