#[non_exhaustive]pub struct ListIntelligenceFindingsResponse {
pub intelligence_findings: Vec<IntelligenceFinding>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message to list the IntelligenceFinding resources associated with
a project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.intelligence_findings: Vec<IntelligenceFinding>The IntelligenceFinding resources from the specified project.
next_page_token: StringA token to retrieve the next page of results.
Pass this value in the page_token field in the subsequent call.
Implementations
Sourceimpl ListIntelligenceFindingsResponse
impl ListIntelligenceFindingsResponse
Sourcepub fn set_intelligence_findings<T, V>(self, v: T) -> Self
pub fn set_intelligence_findings<T, V>(self, v: T) -> Self
Sets the value of intelligence_findings.
Example
ⓘ
use google_cloud_storage::model::IntelligenceFinding;
let x = ListIntelligenceFindingsResponse::new()
.set_intelligence_findings([
IntelligenceFinding::default()/* use setters */,
IntelligenceFinding::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListIntelligenceFindingsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListIntelligenceFindingsResponse
impl Clone for ListIntelligenceFindingsResponse
Sourcefn clone(&self) -> ListIntelligenceFindingsResponse
fn clone(&self) -> ListIntelligenceFindingsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListIntelligenceFindingsResponse
impl Default for ListIntelligenceFindingsResponse
Sourcefn default() -> ListIntelligenceFindingsResponse
fn default() -> ListIntelligenceFindingsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListIntelligenceFindingsResponse
impl PartialEq for ListIntelligenceFindingsResponse
Sourcefn eq(&self, other: &ListIntelligenceFindingsResponse) -> bool
fn eq(&self, other: &ListIntelligenceFindingsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListIntelligenceFindingsResponse