#[non_exhaustive]pub struct ListRapidCachesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub request_id: String,
/* private fields */
}Expand description
Request message for ListRapidCaches.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The bucket to which this cache belongs.
page_size: i32Maximum number of caches to return in a single response. The service will use this parameter or 1,000 items, whichever is smaller.
page_token: StringA previously-returned page token representing part of the larger set of results to view.
request_id: StringOptional. A unique identifier for this request. UUID is the recommended format, but other formats are still accepted.
Implementations
Sourceimpl ListRapidCachesRequest
impl ListRapidCachesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListRapidCachesRequest::new().set_page_token("example");Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = ListRapidCachesRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for ListRapidCachesRequest
impl Clone for ListRapidCachesRequest
Sourcefn clone(&self) -> ListRapidCachesRequest
fn clone(&self) -> ListRapidCachesRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListRapidCachesRequest
impl Debug for ListRapidCachesRequest
Sourceimpl Default for ListRapidCachesRequest
impl Default for ListRapidCachesRequest
Sourcefn default() -> ListRapidCachesRequest
fn default() -> ListRapidCachesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListRapidCachesRequest
impl Message for ListRapidCachesRequest
Sourceimpl PartialEq for ListRapidCachesRequest
impl PartialEq for ListRapidCachesRequest
impl StructuralPartialEq for ListRapidCachesRequest