#[non_exhaustive]pub struct ObjectFullContext {
pub type: Type,
pub key: String,
pub value: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
A full representation of an object context.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: TypeThe type of the object context.
key: StringThe key of the object context, which is unique among contexts of an object.
value: StringThe value of the object context.
create_time: Option<Timestamp>The time at which the object context was created.
update_time: Option<Timestamp>The time at which the object context was updated.
Implementations
Sourceimpl ObjectFullContext
impl ObjectFullContext
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = ObjectFullContext::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = ObjectFullContext::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ObjectFullContext::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = ObjectFullContext::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = ObjectFullContext::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = ObjectFullContext::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for ObjectFullContext
impl Clone for ObjectFullContext
Sourcefn clone(&self) -> ObjectFullContext
fn clone(&self) -> ObjectFullContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjectFullContext
impl Debug for ObjectFullContext
Sourceimpl Default for ObjectFullContext
impl Default for ObjectFullContext
Sourcefn default() -> ObjectFullContext
fn default() -> ObjectFullContext
Returns the “default value” for a type. Read more
Sourceimpl Message for ObjectFullContext
impl Message for ObjectFullContext
Sourceimpl PartialEq for ObjectFullContext
impl PartialEq for ObjectFullContext
impl StructuralPartialEq for ObjectFullContext