RapidCache

Struct RapidCache 

#[non_exhaustive]
pub struct RapidCache { pub name: String, pub zone: String, pub cache_type: String, pub ttl: Option<Duration>, pub admission_policy: String, pub state: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub pending_update: bool, /* private fields */ }
A Rapid Cache Instance.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Immutable. The resource name of this RapidCache. Format: projects/{project}/buckets/{bucket}/rapidCaches/{rapid_cache}

zone: String

Immutable. The zone in which the cache instance is running. For example, us-central1-a.

cache_type: String

Immutable. The type of Rapid Cache this represents. Valid values include: ‘rapid-cache’ and ‘rapid-cache-ultra’.

ttl: Option<Duration>

Cache entry TTL (ranges between 1h to 7d). This is a cache-level config that defines how long a cache entry can live. Default ttl value (24hrs) is applied if not specified in the create request. TTL must be in whole seconds.

admission_policy: String

Cache admission policy. Valid policies includes: no_read_admission, admit-on-first-miss and admit-on-second-miss. Defaults to admit-on-first-miss for both AC and RCU. Default value is applied if not specified in the create request.

state: String

Output only. Cache state including running, creating, and disabled.

create_time: Option<Timestamp>

Output only. Time when Rapid cache instance is allocated.

update_time: Option<Timestamp>

Output only. Time when Rapid cache instance is last updated, including creation.

pending_update: bool

Output only. True if there is an active update operation against this cache instance. Subsequential update requests will be rejected if this field is true. Output only.

Implementations

Source

impl RapidCache

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = RapidCache::new().set_name(format!("projects/{project_id}/buckets/{bucket_id}/rapidCaches/{rapid_cache_id}"));
pub fn set_zone<T: Into<String>>(self, v: T) -> Self

Sets the value of zone.

Example
let x = RapidCache::new().set_zone("example");
pub fn set_cache_type<T: Into<String>>(self, v: T) -> Self

Sets the value of cache_type.

Example
let x = RapidCache::new().set_cache_type("example");
pub fn set_ttl<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of ttl.

Example
use wkt::Duration;
let x = RapidCache::new().set_ttl(Duration::default()/* use setters */);
pub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of ttl.

Example
use wkt::Duration;
let x = RapidCache::new().set_or_clear_ttl(Some(Duration::default()/* use setters */));
let x = RapidCache::new().set_or_clear_ttl(None::<Duration>);
pub fn set_admission_policy<T: Into<String>>(self, v: T) -> Self

Sets the value of admission_policy.

Example
let x = RapidCache::new().set_admission_policy("example");
pub fn set_state<T: Into<String>>(self, v: T) -> Self

Sets the value of state.

Example
let x = RapidCache::new().set_state("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = RapidCache::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = RapidCache::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = RapidCache::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = RapidCache::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = RapidCache::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = RapidCache::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_pending_update<T: Into<bool>>(self, v: T) -> Self

Sets the value of pending_update.

Example
let x = RapidCache::new().set_pending_update(true);