#[non_exhaustive]pub struct SummarizeIntelligenceFindingsRequest {
pub parent: String,
pub resource_scope: ResourceScope,
pub filter: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message to summarize the intelligence findings for the specified scope(org, folder or project).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The scope to summarize the findings for. Format:
organizations/{organization}/locations/{location}folders/{folder}/locations/{location}projects/{project}/locations/{location}
resource_scope: ResourceScopeOptional. Determines the granularity of the findings
when the parent is an organization or folder.
PARENT(or not set): A single summary is returned for each insight type, aggregated across the entireparentscope.PROJECT: A separate summary is returned for each insight type for every project within theparentscope.
The only supported values are PARENT and PROJECT.
If no value is specified, the API behaviour defaults to the PARENT.
filter: StringOptional. The filter expression, following AIP-160. Supports filtering by FindingType.
page_size: i32Optional. The maximum number of findings to return.
The maximum value is 100; values above 100 will be coerced to 100.
The default value is 100.
page_token: StringOptional. A page token, received from a previous
SummarizeIntelligenceFindings call. Provide this to retrieve the
subsequent page.
When paginating, all other parameters provided to
SummarizeIntelligenceFindings must match the call that provided the page
token.
Implementations
Sourceimpl SummarizeIntelligenceFindingsRequest
impl SummarizeIntelligenceFindingsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_resource_scope<T: Into<ResourceScope>>(self, v: T) -> Self
pub fn set_resource_scope<T: Into<ResourceScope>>(self, v: T) -> Self
Sets the value of resource_scope.
Example
use google_cloud_storage::model::summarize_intelligence_findings_request::ResourceScope;
let x0 = SummarizeIntelligenceFindingsRequest::new().set_resource_scope(ResourceScope::Parent);
let x1 = SummarizeIntelligenceFindingsRequest::new().set_resource_scope(ResourceScope::Project);Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = SummarizeIntelligenceFindingsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for SummarizeIntelligenceFindingsRequest
impl Clone for SummarizeIntelligenceFindingsRequest
Sourcefn clone(&self) -> SummarizeIntelligenceFindingsRequest
fn clone(&self) -> SummarizeIntelligenceFindingsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for SummarizeIntelligenceFindingsRequest
impl Default for SummarizeIntelligenceFindingsRequest
Sourcefn default() -> SummarizeIntelligenceFindingsRequest
fn default() -> SummarizeIntelligenceFindingsRequest
Sourceimpl PartialEq for SummarizeIntelligenceFindingsRequest
impl PartialEq for SummarizeIntelligenceFindingsRequest
Sourcefn eq(&self, other: &SummarizeIntelligenceFindingsRequest) -> bool
fn eq(&self, other: &SummarizeIntelligenceFindingsRequest) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SummarizeIntelligenceFindingsRequest