#[non_exhaustive]pub struct SummarizeIntelligenceFindingsResponse {
pub finding_summaries: Vec<FindingSummary>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message to summarize the intelligence findings for a specified scope(org, folder or project).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.finding_summaries: Vec<FindingSummary>The list of FindingSummary summaries.
next_page_token: StringA token to retrieve the next page of results.
Pass this value in the page_token field in the subsequent call to
SummarizeIntelligenceFindings to retrieve the next page of results.
Implementations
Sourceimpl SummarizeIntelligenceFindingsResponse
impl SummarizeIntelligenceFindingsResponse
Sourcepub fn set_finding_summaries<T, V>(self, v: T) -> Self
pub fn set_finding_summaries<T, V>(self, v: T) -> Self
Sets the value of finding_summaries.
Example
ⓘ
use google_cloud_storage::model::FindingSummary;
let x = SummarizeIntelligenceFindingsResponse::new()
.set_finding_summaries([
FindingSummary::default()/* use setters */,
FindingSummary::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = SummarizeIntelligenceFindingsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for SummarizeIntelligenceFindingsResponse
impl Clone for SummarizeIntelligenceFindingsResponse
Sourcefn clone(&self) -> SummarizeIntelligenceFindingsResponse
fn clone(&self) -> SummarizeIntelligenceFindingsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SummarizeIntelligenceFindingsResponse
impl Default for SummarizeIntelligenceFindingsResponse
Sourcefn default() -> SummarizeIntelligenceFindingsResponse
fn default() -> SummarizeIntelligenceFindingsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for SummarizeIntelligenceFindingsResponse
impl PartialEq for SummarizeIntelligenceFindingsResponse
Sourcefn eq(&self, other: &SummarizeIntelligenceFindingsResponse) -> bool
fn eq(&self, other: &SummarizeIntelligenceFindingsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SummarizeIntelligenceFindingsResponse