#[non_exhaustive]pub struct UpdateRapidCacheMetadata {
pub common_metadata: Option<CommonLongRunningOperationMetadata>,
pub rapid_cache_id: Option<String>,
pub zone: Option<String>,
pub ttl: Option<Duration>,
pub admission_policy: Option<String>,
pub ingest_on_write: Option<bool>,
pub cache_type: Option<String>,
/* private fields */
}Expand description
Message returned in the metadata field of the Operation resource for UpdateRapidCache operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.common_metadata: Option<CommonLongRunningOperationMetadata>Generic metadata for the long running operation.
rapid_cache_id: Option<String>Rapid Cache ID.
zone: Option<String>The zone in which the cache instance is running. For example, us-central1-a.
ttl: Option<Duration>Rapid Cache entry’s TTL between 1h and 7days. A cache-level config that
is applied to all new cache entries on admission. If ttl is pending
update, this field equals to the new value specified in the Update request.
admission_policy: Option<String>Optional. Rapid Cache entry Admission Policy in kebab-case (e.g.,
“admit-on-first-miss”). If admission_policy is pending
update, this field equals to the new value specified in the Update request.
ingest_on_write: Option<bool>Specifies whether objects are ingested into the cache upon write. If not set, it defaults to false.
cache_type: Option<String>Optional. The type of cache. Either rapid cache or rapid cache ultra.
Implementations
Sourceimpl UpdateRapidCacheMetadata
impl UpdateRapidCacheMetadata
Sourcepub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_common_metadata<T>(self, v: T) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets the value of common_metadata.
Example
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = UpdateRapidCacheMetadata::new().set_common_metadata(CommonLongRunningOperationMetadata::default()/* use setters */);Sourcepub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
pub fn set_or_clear_common_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommonLongRunningOperationMetadata>,
Sets or clears the value of common_metadata.
Example
use google_cloud_storage::model::CommonLongRunningOperationMetadata;
let x = UpdateRapidCacheMetadata::new().set_or_clear_common_metadata(Some(CommonLongRunningOperationMetadata::default()/* use setters */));
let x = UpdateRapidCacheMetadata::new().set_or_clear_common_metadata(None::<CommonLongRunningOperationMetadata>);Sourcepub fn set_rapid_cache_id<T>(self, v: T) -> Self
pub fn set_rapid_cache_id<T>(self, v: T) -> Self
Sets the value of rapid_cache_id.
Example
let x = UpdateRapidCacheMetadata::new().set_rapid_cache_id("example");Sourcepub fn set_or_clear_rapid_cache_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_rapid_cache_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of rapid_cache_id.
Example
let x = UpdateRapidCacheMetadata::new().set_or_clear_rapid_cache_id(Some("example"));
let x = UpdateRapidCacheMetadata::new().set_or_clear_rapid_cache_id(None::<String>);Sourcepub fn set_or_clear_zone<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_zone<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
Sourcepub fn set_admission_policy<T>(self, v: T) -> Self
pub fn set_admission_policy<T>(self, v: T) -> Self
Sets the value of admission_policy.
Example
let x = UpdateRapidCacheMetadata::new().set_admission_policy("example");Sourcepub fn set_or_clear_admission_policy<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_admission_policy<T>(self, v: Option<T>) -> Self
Sets or clears the value of admission_policy.
Example
let x = UpdateRapidCacheMetadata::new().set_or_clear_admission_policy(Some("example"));
let x = UpdateRapidCacheMetadata::new().set_or_clear_admission_policy(None::<String>);Sourcepub fn set_ingest_on_write<T>(self, v: T) -> Self
pub fn set_ingest_on_write<T>(self, v: T) -> Self
Sets the value of ingest_on_write.
Example
let x = UpdateRapidCacheMetadata::new().set_ingest_on_write(true);Sourcepub fn set_or_clear_ingest_on_write<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ingest_on_write<T>(self, v: Option<T>) -> Self
Sets or clears the value of ingest_on_write.
Example
let x = UpdateRapidCacheMetadata::new().set_or_clear_ingest_on_write(Some(false));
let x = UpdateRapidCacheMetadata::new().set_or_clear_ingest_on_write(None::<bool>);Sourcepub fn set_cache_type<T>(self, v: T) -> Self
pub fn set_cache_type<T>(self, v: T) -> Self
Sets the value of cache_type.
Example
let x = UpdateRapidCacheMetadata::new().set_cache_type("example");Sourcepub fn set_or_clear_cache_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cache_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of cache_type.
Example
let x = UpdateRapidCacheMetadata::new().set_or_clear_cache_type(Some("example"));
let x = UpdateRapidCacheMetadata::new().set_or_clear_cache_type(None::<String>);Trait Implementations
Sourceimpl Clone for UpdateRapidCacheMetadata
impl Clone for UpdateRapidCacheMetadata
Sourcefn clone(&self) -> UpdateRapidCacheMetadata
fn clone(&self) -> UpdateRapidCacheMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateRapidCacheMetadata
impl Debug for UpdateRapidCacheMetadata
Sourceimpl Default for UpdateRapidCacheMetadata
impl Default for UpdateRapidCacheMetadata
Sourcefn default() -> UpdateRapidCacheMetadata
fn default() -> UpdateRapidCacheMetadata
Sourceimpl Message for UpdateRapidCacheMetadata
impl Message for UpdateRapidCacheMetadata
Sourceimpl PartialEq for UpdateRapidCacheMetadata
impl PartialEq for UpdateRapidCacheMetadata
impl StructuralPartialEq for UpdateRapidCacheMetadata