#[non_exhaustive]pub struct UpdateRapidCacheRequest {
pub rapid_cache: Option<RapidCache>,
pub update_mask: Option<FieldMask>,
pub request_id: String,
/* private fields */
}Expand description
Request message for UpdateRapidCache.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rapid_cache: Option<RapidCache>Required. The RapidCache to update.
update_mask: Option<FieldMask>Required. List of fields to be updated. Mutable fields of RapidCache
include ttl, admission_policy and ingest_on_write.
To specify ALL fields, specify a single field with the value *. Note: We
recommend against doing this. If a new field is introduced at a later time,
an older client updating with the * may accidentally reset the new
field’s value.
Not specifying any fields is an error.
request_id: StringOptional. A unique identifier for this request. UUID is the recommended
format, but other formats are still accepted. This request is only
idempotent if a request_id is provided.
Implementations
Sourceimpl UpdateRapidCacheRequest
impl UpdateRapidCacheRequest
Sourcepub fn set_rapid_cache<T>(self, v: T) -> Selfwhere
T: Into<RapidCache>,
pub fn set_rapid_cache<T>(self, v: T) -> Selfwhere
T: Into<RapidCache>,
Sets the value of rapid_cache.
Example
use google_cloud_storage::model::RapidCache;
let x = UpdateRapidCacheRequest::new().set_rapid_cache(RapidCache::default()/* use setters */);Sourcepub fn set_or_clear_rapid_cache<T>(self, v: Option<T>) -> Selfwhere
T: Into<RapidCache>,
pub fn set_or_clear_rapid_cache<T>(self, v: Option<T>) -> Selfwhere
T: Into<RapidCache>,
Sets or clears the value of rapid_cache.
Example
use google_cloud_storage::model::RapidCache;
let x = UpdateRapidCacheRequest::new().set_or_clear_rapid_cache(Some(RapidCache::default()/* use setters */));
let x = UpdateRapidCacheRequest::new().set_or_clear_rapid_cache(None::<RapidCache>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateRapidCacheRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateRapidCacheRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateRapidCacheRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateRapidCacheRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateRapidCacheRequest
impl Clone for UpdateRapidCacheRequest
Sourcefn clone(&self) -> UpdateRapidCacheRequest
fn clone(&self) -> UpdateRapidCacheRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateRapidCacheRequest
impl Debug for UpdateRapidCacheRequest
Sourceimpl Default for UpdateRapidCacheRequest
impl Default for UpdateRapidCacheRequest
Sourcefn default() -> UpdateRapidCacheRequest
fn default() -> UpdateRapidCacheRequest
Sourceimpl Message for UpdateRapidCacheRequest
impl Message for UpdateRapidCacheRequest
Sourceimpl PartialEq for UpdateRapidCacheRequest
impl PartialEq for UpdateRapidCacheRequest
impl StructuralPartialEq for UpdateRapidCacheRequest