pub struct RequestOptions { /* private fields */ }Expand description
The per-request options for a client call.
This is currently an opaque type, used only in mocking the Storage client.
It is opaque to avoid breaking changes until its interface stabilizes.
Implementations
Sourceimpl RequestOptions
impl RequestOptions
Sourcepub fn set_read_resume_policy(&mut self, v: Arc<dyn ReadResumePolicy>)
pub fn set_read_resume_policy(&mut self, v: Arc<dyn ReadResumePolicy>)
Sets the read resume policy.
Sourcepub fn read_resume_policy(&self) -> Arc<dyn ReadResumePolicy>
pub fn read_resume_policy(&self) -> Arc<dyn ReadResumePolicy>
Returns the read resume policy.
Sourcepub fn set_resumable_upload_threshold(&mut self, v: usize)
pub fn set_resumable_upload_threshold(&mut self, v: usize)
Sets the threshold for resumable uploads.
Sourcepub fn resumable_upload_threshold(&self) -> usize
pub fn resumable_upload_threshold(&self) -> usize
Returns the threshold for resumable uploads.
Sourcepub fn set_resumable_upload_buffer_size(&mut self, v: usize)
pub fn set_resumable_upload_buffer_size(&mut self, v: usize)
Sets the buffer size for resumable uploads.
Sourcepub fn set_bidi_attempt_timeout(&mut self, v: Duration)
pub fn set_bidi_attempt_timeout(&mut self, v: Duration)
Sets the timeout for bidirectional streaming attempts.
Sourcepub fn resumable_upload_buffer_size(&self) -> usize
pub fn resumable_upload_buffer_size(&self) -> usize
Returns the buffer size for resumable uploads.
Sourcepub fn with_user_agent(&mut self, v: impl Into<String>)
pub fn with_user_agent(&mut self, v: impl Into<String>)
Appends a user agent string to the request.
Sourcepub fn set_quota_project(&mut self, v: impl Into<String>)
pub fn set_quota_project(&mut self, v: impl Into<String>)
Sets the project that will be billed for this request.