#[non_exhaustive]pub struct SummaryDetails {
pub resource_type: ResourceType,
pub description: String,
pub magnitude: Option<Magnitude>,
/* private fields */
}Expand description
Details about the FindingSummary resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_type: ResourceTypeOutput only. The type of Cloud resource this summary detail applies to.
description: StringOutput only. A short description about the FindingSummary
magnitude: Option<Magnitude>The value of the summary.
Implementations
Sourceimpl SummaryDetails
impl SummaryDetails
Sourcepub fn set_resource_type<T: Into<ResourceType>>(self, v: T) -> Self
pub fn set_resource_type<T: Into<ResourceType>>(self, v: T) -> Self
Sets the value of resource_type.
Example
ⓘ
use google_cloud_storage::model::finding_summary::summary_details::ResourceType;
let x0 = SummaryDetails::new().set_resource_type(ResourceType::Project);
let x1 = SummaryDetails::new().set_resource_type(ResourceType::Bucket);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_magnitude<T: Into<Option<Magnitude>>>(self, v: T) -> Self
pub fn set_magnitude<T: Into<Option<Magnitude>>>(self, v: T) -> Self
Sourcepub fn count(&self) -> Option<&i64>
pub fn count(&self) -> Option<&i64>
The value of magnitude
if it holds a Count, None if the field is not set or
holds a different branch.
Sourcepub fn percentage(&self) -> Option<&f32>
pub fn percentage(&self) -> Option<&f32>
The value of magnitude
if it holds a Percentage, None if the field is not set or
holds a different branch.
Sourcepub fn set_percentage<T: Into<f32>>(self, v: T) -> Self
pub fn set_percentage<T: Into<f32>>(self, v: T) -> Self