Defines additional types related to IntelligenceFinding.
Modules
- coldline_
and_ archival_ storage_ operations_ spike - Defines additional types related to ColdlineAndArchivalStorageOperationsSpike.
- cross_
region_ egress_ spike - Defines additional types related to CrossRegionEgressSpike.
- storage_
growth_ above_ trend - Defines additional types related to StorageGrowthAboveTrend.
- throttled_
request_ spike - Defines additional types related to ThrottledRequestSpike.
Structs
- Coldline
AndArchival Storage Operations Spike - Represents a finding about a spike in Class A/B operations on Coldline
or Archive Cloud Storage objects.
This corresponds to the
COLD_AND_ARCHIVAL_STORAGE_OPERATIONS_SPIKEfinding type. - Cross
Region Egress Spike - Represents a finding about a spike in cross-region egress from Cloud
Storage.
This corresponds to the
CROSS_REGION_EGRESS_SPIKEfinding type. - Storage
Growth Above Trend - Represents a finding about a storage growth above the expected trend.
This corresponds to the
STORAGE_GROWTH_ABOVE_TRENDfinding type. - Throttled
Request Spike - Represents a finding about a spike in throttled requests (429 errors)
within a project.
This corresponds to the
THROTTLED_REQUEST_SPIKEfinding type.
Enums
- Intelligence
Finding Details - The specific details of the
IntelligenceFinding.