Defines additional types related to ManagedFolder.
Modules
- rapid_
cache_ config - Defines additional types related to RapidCacheConfig.
Structs
- Rapid
Cache Config - Rapid Cache configuration for a managed prefix. This configuration is used to determine how the rapid cache behaves for objects under the managed folder.