#[non_exhaustive]pub struct RapidCache {
pub name: String,
pub zone: String,
pub cache_type: String,
pub ttl: Option<Duration>,
pub admission_policy: String,
pub state: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub pending_update: bool,
/* private fields */
}Expand description
A Rapid Cache Instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. The resource name of this RapidCache. Format: projects/{project}/buckets/{bucket}/rapidCaches/{rapid_cache}
zone: StringImmutable. The zone in which the cache instance is running. For example, us-central1-a.
cache_type: StringImmutable. The type of Rapid Cache this represents. Valid values include: ‘rapid-cache’ and ‘rapid-cache-ultra’.
ttl: Option<Duration>Cache entry TTL (ranges between 1h to 7d). This is a cache-level config that defines how long a cache entry can live. Default ttl value (24hrs) is applied if not specified in the create request. TTL must be in whole seconds.
admission_policy: StringCache admission policy. Valid policies includes: no_read_admission, admit-on-first-miss and admit-on-second-miss. Defaults to admit-on-first-miss for both AC and RCU. Default value is applied if not specified in the create request.
state: StringOutput only. Cache state including running, creating, and disabled.
create_time: Option<Timestamp>Output only. Time when Rapid cache instance is allocated.
update_time: Option<Timestamp>Output only. Time when Rapid cache instance is last updated, including creation.
pending_update: boolOutput only. True if there is an active update operation against this cache instance. Subsequential update requests will be rejected if this field is true. Output only.
Implementations
Sourceimpl RapidCache
impl RapidCache
Sourcepub fn set_cache_type<T: Into<String>>(self, v: T) -> Self
pub fn set_cache_type<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
Sourcepub fn set_admission_policy<T: Into<String>>(self, v: T) -> Self
pub fn set_admission_policy<T: Into<String>>(self, v: T) -> Self
Sets the value of admission_policy.
Example
let x = RapidCache::new().set_admission_policy("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = RapidCache::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = RapidCache::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = RapidCache::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = RapidCache::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = RapidCache::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = RapidCache::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_pending_update<T: Into<bool>>(self, v: T) -> Self
pub fn set_pending_update<T: Into<bool>>(self, v: T) -> Self